@@ -1,11 +1,14 @@
 import base64
 from . import *
-import logging, sys
 
 # Create the logger for the SDK
+import logging, sys
 logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.Logger('GX SDK')
+log = logging.Logger('GX_SDK')
 
+# logger_handler = logging.StreamHandler()
+# log.addHandler(logger_handler)
+# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
 
 
 class Authenticator:
