@@ -1,14 +1,21 @@
-#import northgravity_python_sdk.northgravity as ng
-import northgravity_python_sdk.generalindex as ng
+# for easy testing, bring this file out of the test folder, rename folder to northgravity_sdk:
+#import northgravity_sdk as ng
+import northgravity_python_sdk.northgravity as ng
 import logging; log=logging.getLogger()
+
+
 import time
 import pandas as pd
 import io, os
+#--------------
+# Test datasets for I/O
+os.environ['First Dataset'] = "{'name': 'prepared_data.csv', 'groupName': 'Tests_Damien'}"
+os.environ['Output'] = "{'name': 'prepared_data.csv', 'groupName': 'Tests_Damien'}"
 
 #--------------
 # Search List of symbols - Test
 ts = ng.Timeseries()
-print(ts.get_symbols('Tests_Damien'))
+print(ts.get_symbols('Tests_Damien', _size=100))
 
 
 #--------------
@@ -18,16 +25,16 @@ print('-' * 110)
 ts = ng.Timeseries()
 
 # Symbols to query from database
-symbols = {"Crop": "Soybean Meal", "Dest": "*"}
-columns = ['Vol']
+symbols = {'Symbol': '*'}
+columns = []
 
 # retrieve all available data and save as test.csv
 fileIO = ts.retrieve_data_as_csv(file_name=None,
                                  symbols=symbols,
                                  columns=columns,
-                                 group_name='Test Test Test',
+                                 group_name='Concord History',
                                  metadata=True,
-                                 timezone='Asia/Singapore',
+                                 timezone='Europe/Warsaw',
                                  allow_wildcard=True,
                                  NCSV=False
                                  )
@@ -103,7 +110,7 @@ ts = ng.Timeseries()
 
 
 symbols = {'Symbol': "CUA"}
-columns = 'Open'
+columns = ['Open']
 
 ts.retrieve_data_as_csv(file_name='test/ts_test.csv',
                         symbols=symbols,
